queryStore.SimpleQueryStore

|  | ## Cheshire3 Object Model: Class SimpleQueryStore

Module queryStore :: Class SimpleQueryStore

## Class SimpleQueryStore
source code

Object Tree:

               object --+
                        |
    configParser.C3Object --+
                            |
                  SimpleStore --+
                                |
               baseStore.BdbStore --+
                                    |
               object --+           |
                        |           |
    configParser.C3Object --+       |
                            |       |
                  ObjectStore --+   |
                                |   |
           baseObjects.QueryStore --+
                                    |
                                   SimpleQueryStore

Instance Methods

create_query(self, session, query=None) Create a new query in the store.
delete_query(self, session, id) Delete a query from the store.
fetch_query(self, session, id) Fetch a query from the store.
store_query(self, session, query) Store a query, potentially overwriting an existing copy.
Inherited from `baseStore.BdbStore`: `__iter__`, `begin_storing`, `clean`, `commit_storing`, `delete_item`, `fetch_checksum`, `fetch_data`, `fetch_idList`, `fetch_size`, `generate_id`, `get_dbsize`, `store_checkSum`, `store_data`, `verify_checkSum` Inherited from `baseStore.BdbStore` (private): `_closeContainer`, `_initialise`, `_openContainer`, `_verifyDatabase`, `_verifyDatabases` Inherited from `baseStore.SimpleStore`: `__init__` Inherited from `baseObjects.QueryStore`: `fetch_queryList` Inherited from `baseObjects.ObjectStore`: `create_object`, `delete_object`, `fetch_object`, `store_object` Inherited from `configParser.C3Object`: `auth_function`, `get_config`, `get_default`, `get_object`, `get_path`, `get_setting`, `log_function`, `unauth_function`, `unlog_function` Inherited from `configParser.C3Object` (private): `_getDomFromFile`, `_handleConfigNode`, `_parseIncludes`, `_recurseSubConfigs`, `_verifyDefault`, `_verifyOption`, `_verifySetting` Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__str__`

Class Variables

Inherited from `baseStore.BdbStore`: `cxn`, `digestCxn`, `digestForId` Inherited from `baseStore.SimpleStore`: `currentId`, `idNormalizer` Inherited from `configParser.C3Object`: `configStore`, `defaults`, `functionLogger`, `id`, `name`, `objectType`, `objects`, `parent`, `paths`, `permissionHandlers`, `settings`, `subConfigs`, `unresolvedObjects` Inherited from `configParser.C3Object` (private): `_includeConfigStores`, `_objectRefs` Inherited from `object`: `__class__`

Method Details

### create_query(self, session, query=None) | source code
Create a new query in the store. Overrides: baseObjects.QueryStore.create_query (inherited documentation)

### delete_query(self, session, id) | source code
Delete a query from the store. Overrides: baseObjects.QueryStore.delete_query (inherited documentation)

### fetch_query(self, session, id) | source code
Fetch a query from the store. Overrides: baseObjects.QueryStore.fetch_query (inherited documentation)

### store_query(self, session, query) | source code
Store a query, potentially overwriting an existing copy. Overrides: baseObjects.QueryStore.store_query (inherited documentation)